<?php

defined('ABSPATH') || exit;

if (!function_exists('elementor_pro_render_mini_cart_item')) {
	function elementor_pro_render_mini_cart_item($cart_item_key, $cart_item)
	{
		$_product = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);
		$is_product_visible = ($_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key));

		if (!$is_product_visible) {
			return;
		}

		$product_id = apply_filters('woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key);
		$product_price = apply_filters('woocommerce_cart_item_price', WC()->cart->get_product_price($_product), $cart_item, $cart_item_key);
		$product_permalink = apply_filters('woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink($cart_item) : '', $cart_item, $cart_item_key);
?>
		<div class="elementor-menu-cart__product woocommerce-cart-form__cart-item <?php echo esc_attr(apply_filters('woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key)); ?>">

			<div class="elementor-menu-cart__product-image product-thumbnail">
				<?php
				$thumbnail = apply_filters('woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key);

				if (!$product_permalink) :
					echo wp_kses_post($thumbnail);
				else :
					printf('<a href="%s">%s</a>', esc_url($product_permalink), wp_kses_post($thumbnail));
				endif;
				?>
			</div>

			<div class="elementor-menu-cart__product-name product-name" data-title="<?php esc_attr_e('Product', 'elementor-pro'); ?>">
				<?php
				if (!$product_permalink) :
					echo wp_kses_post(apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key) . '&nbsp;');
				else :
					echo wp_kses_post(apply_filters('woocommerce_cart_item_name', sprintf('<a href="%s">%s</a>', esc_url($product_permalink), $_product->get_name()), $cart_item, $cart_item_key));
				endif;

				do_action('woocommerce_after_cart_item_name', $cart_item, $cart_item_key);

				// Meta data.
				echo wc_get_formatted_cart_item_data($cart_item); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				?>
			</div>

			<div class="mini-cart-qnt quantity" style="display: flex;">
				<?php
				echo '<a class="btnPlus" onClick="updateQty(\'' . $cart_item_key . '\',' . ($cart_item['quantity'] + 1) . ')"> + </a>';
				echo "<input type='number' data-key='$cart_item_key'  value='" . $cart_item['quantity'] . "'>";
				echo '<a class="btnMinus" onClick="updateQty(\'' . $cart_item_key . '\',' . ($cart_item['quantity'] - 1) . ')"> - </a>';
				?>
			</div>
			<div class="elementor-menu-cart__product-price product-price" data-title="<?php esc_attr_e('Price', 'elementor-pro'); ?>">
				<?php echo apply_filters('woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf('<span class="product-quantity">%s &times;</span> %s', $cart_item['quantity'], $product_price) . '</span>', $cart_item, $cart_item_key); ?>
			</div>

			<div class="elementor-menu-cart__product-remove product-remove">
				<?php foreach (['elementor_remove_from_cart_button', 'remove_from_cart_button'] as $class) {
					echo apply_filters('woocommerce_cart_item_remove_link', sprintf( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
						'<a href="%s" class="%s" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s"></a>',
						esc_url(wc_get_cart_remove_url($cart_item_key)),
						$class,
						__('Remove this item', 'elementor-pro'),
						esc_attr($product_id),
						esc_attr($cart_item_key),
						esc_attr($_product->get_sku())
					), $cart_item_key);
				} ?>
			</div>
		</div>
	<?php
	}
}

$cart_items = WC()->cart->get_cart();

if (empty($cart_items)) { ?>
	<div class="woocommerce-mini-cart__empty-message"><?php esc_attr_e('No products in the cart.', 'elementor-pro'); ?></div>
<?php } else { ?>
	<div class="elementor-menu-cart__products woocommerce-mini-cart cart woocommerce-cart-form__contents">
		<div class="lodgin-mini-cart-item">
			<div class="loading-mini-cart"></div>
		</div>
		<?php
		do_action('woocommerce_before_mini_cart_contents');

		foreach ($cart_items as $cart_item_key => $cart_item) {
			elementor_pro_render_mini_cart_item($cart_item_key, $cart_item);
		}
		?>
		<?php do_action('woocommerce_cart_actions');
		do_action('woocommerce_mini_cart_contents');
		?>

	</div>

	<div class="elementor-menu-cart__subtotal">
		<strong><?php echo esc_html__('Subtotal', 'woocommerce'); // phpcs:ignore WordPress.WP.I18n 
				?>:</strong>
		<?php echo WC()->cart->get_cart_subtotal(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped 
		?>
	</div>

	<?php do_action('woocommerce_widget_shopping_cart_before_buttons'); ?>

	<div class="elementor-menu-cart__footer-buttons">
		<a href="<?php echo esc_url(wc_get_cart_url()); ?>" class="elementor-button elementor-button--view-cart elementor-size-md">
			<span class="elementor-button-text"><?php echo esc_html__('View cart', 'woocommerce'); // phpcs:ignore WordPress.WP.I18n 
												?></span>
		</a>
		<a href="<?php echo esc_url(wc_get_checkout_url()); ?>" class="elementor-button elementor-button--checkout elementor-size-md">
			<span class="elementor-button-text"><?php echo esc_html__('Checkout', 'woocommerce'); // phpcs:ignore WordPress.WP.I18n 
												?></span>
		</a>
	</div>
<?php
} // empty( $cart_items )
?>

<script type="text/javascript">
	jQuery(document).ready(function() {
		jQuery(".mini-cart-qnt input").change(function() {
			var qval = jQuery(this).val();
			var qkey = jQuery(this).attr("data-key");

			url = 'https://wordpress-751516-2558864.cloudwaysapps.com/updatecart/';
			data = "cart_item_key=" + qkey + "&cart_item_qty=" + qval;

			jQuery.post(url, data).done(function(data) {
				//function updateCartFragment 
				updateCartFragment();
			});
		});
	});
	jQuery(document).on({
		ajaxStart: function() {
			jQuery(".elementor-menu-cart__main .woocommerce-mini-cart.cart").addClass("loader");
		},
		ajaxStop: function() {
			jQuery(".elementor-menu-cart__main .woocommerce-mini-cart.cart").removeClass("loader");
		}
	});

	function updateQty(key, qty) {
		url = 'https://wordpress-751516-2558864.cloudwaysapps.com/updatecart/';
		data = "cart_item_key=" + key + "&cart_item_qty=" + qty;

		jQuery.post(url, data).done(function(data) {
			//function updateCartFragment 
			updateCartFragment();
		});
	}

	function updateCartFragment() {
		$fragment_refresh = {
			url: woocommerce_params.ajax_url,
			type: 'POST',
			data: {
				action: 'woocommerce_get_refreshed_fragments'
			},
			success: function(data) {
				if (data && data.fragments) {
					jQuery.each(data.fragments, function(key, value) {
						jQuery(key).replaceWith(value);
					});

					function supports_html5_storage() {
						try {
							return 'localStorage' in window && window['localStorage'] !== null;
						} catch (e) {
							return false;
						}
					}

					if (supports_html5_storage) {
						sessionStorage.setItem("wc_fragments", JSON.stringify(data.fragments));
						sessionStorage.setItem("wc_cart_hash", data.cart_hash);
					}
					jQuery('body').trigger('wc_fragments_refreshed');
				}
			}
		};

		//Always perform fragment refresh
		jQuery.ajax($fragment_refresh);
	}
</script>